@import url('https://fonts.googleapis.com/css2?family=Public+Sans:ital,wght@0,400;0,500;0,700;1,400;1,500;1,700&family=Space+Grotesk:wght@400;500;700&display=swap');

// ember theme: orange/amber color scheme

:root {
  --accent: rgb(249, 115, 22);
  --accent-alpha-70: rgba(249, 115, 22, .7);
  --accent-alpha-20: rgba(249, 115, 22, .2);
  --accent-secondary: rgb(251, 191, 36);
  --accent-secondary-alpha-20: rgba(251, 191, 36, .2);
  --background: #1a0f0a;
  --background-raised: #241810;
  --color: #f0e2d0;
  --color-muted: rgba(240, 226, 208, .5);
  --border-color: rgba(249, 115, 22, .15);
  --code-bg: rgba(0, 0, 0, 0.3);
  --max-width: 1200px;
}

[data-theme="light"] {
  --background: #fdf6ee;
  --background-raised: #ffffff;
  --color: #3b1e08;
  --color-muted: rgba(59, 30, 8, .5);
  --border-color: rgba(249, 115, 22, .15);
  --code-bg: #fef3e2;
}

$phone-max-width: 683px;
$tablet-max-width: 899px;
$nav-collapse-width: 600px;

@import 'structure';
@import 'components';
