@import url('https://fonts.googleapis.com/css2?family=Playfair+Display:ital,wght@0,400;0,500;0,700;1,400;1,500;1,700&display=swap');

// plum theme: purple/lavender color scheme

:root {
  --accent: rgb(168, 85, 247);
  --accent-alpha-70: rgba(168, 85, 247, .7);
  --accent-alpha-20: rgba(168, 85, 247, .2);
  --accent-secondary: rgb(196, 181, 253);
  --accent-secondary-alpha-20: rgba(196, 181, 253, .2);
  --background: #140a1e;
  --background-raised: #1e1028;
  --color: #e4d0f0;
  --color-muted: rgba(228, 208, 240, .5);
  --border-color: rgba(168, 85, 247, .15);
  --code-bg: rgba(0, 0, 0, 0.3);
  --max-width: 1200px;
}

[data-theme="light"] {
  --background: #f8f0fd;
  --background-raised: #ffffff;
  --color: #2e0a4a;
  --color-muted: rgba(46, 10, 74, .5);
  --border-color: rgba(168, 85, 247, .15);
  --code-bg: #ede9fe;
}

$phone-max-width: 683px;
$tablet-max-width: 899px;
$nav-collapse-width: 600px;

@import 'structure';
@import 'components';
