@import url('https://fonts.googleapis.com/css2?family=Libre+Baskerville:ital,wght@0,400;0,700;1,400&display=swap');

// sunset theme: red/orange color scheme

:root {
  --accent: rgb(239, 68, 68);
  --accent-alpha-70: rgba(239, 68, 68, .7);
  --accent-alpha-20: rgba(239, 68, 68, .2);
  --accent-secondary: rgb(251, 146, 60);
  --accent-secondary-alpha-20: rgba(251, 146, 60, .2);
  --background: #1a0a0a;
  --background-raised: #241210;
  --color: #f0d0c8;
  --color-muted: rgba(240, 208, 200, .5);
  --border-color: rgba(239, 68, 68, .15);
  --code-bg: rgba(0, 0, 0, 0.3);
  --max-width: 1200px;
}

[data-theme="light"] {
  --background: #fdf2ee;
  --background-raised: #ffffff;
  --color: #3b0808;
  --color-muted: rgba(59, 8, 8, .5);
  --border-color: rgba(239, 68, 68, .15);
  --code-bg: #fee2e2;
}

$phone-max-width: 683px;
$tablet-max-width: 899px;
$nav-collapse-width: 600px;

@import 'structure';
@import 'components';
