@import url('https://fonts.googleapis.com/css2?family=DM+Sans:ital,wght@0,400;0,500;0,700;1,400;1,500;1,700&display=swap');

// mint theme: green/cyan color scheme

:root {
  --accent: rgb(52, 211, 153);
  --accent-alpha-70: rgba(52, 211, 153, .7);
  --accent-alpha-20: rgba(52, 211, 153, .2);
  --accent-secondary: rgb(34, 211, 238);
  --accent-secondary-alpha-20: rgba(34, 211, 238, .2);
  --background: #0a1a14;
  --background-raised: #10241c;
  --color: #d0f0e4;
  --color-muted: rgba(208, 240, 228, .5);
  --border-color: rgba(52, 211, 153, .15);
  --code-bg: rgba(0, 0, 0, 0.3);
  --max-width: 1200px;
}

[data-theme="light"] {
  --background: #eefdf6;
  --background-raised: #ffffff;
  --color: #0a3b24;
  --color-muted: rgba(10, 59, 36, .5);
  --border-color: rgba(52, 211, 153, .15);
  --code-bg: #d1fae5;
}

$phone-max-width: 683px;
$tablet-max-width: 899px;
$nav-collapse-width: 600px;

@import 'structure';
@import 'components';
