@import url('https://fonts.googleapis.com/css2?family=Public+Sans:ital,wght@0,400;0,500;0,700;1,400;1,500;1,700&family=Space+Grotesk:wght@400;500;700&display=swap');

// ocean theme: teal/blue color scheme

:root {
  --accent: rgb(13, 148, 136);
  --accent-alpha-70: rgba(13, 148, 136, .7);
  --accent-alpha-20: rgba(13, 148, 136, .2);
  --accent-secondary: rgb(59, 130, 246);
  --accent-secondary-alpha-20: rgba(59, 130, 246, .2);
  --background: #0a1628;
  --background-raised: #0f1e34;
  --color: #cde0f0;
  --color-muted: rgba(205, 224, 240, .5);
  --border-color: rgba(13, 148, 136, .15);
  --code-bg: rgba(0, 0, 0, 0.3);
  --max-width: 1200px;
}

[data-theme="light"] {
  --background: #f8fafb;
  --background-raised: #ffffff;
  --color: #1a2e38;
  --color-muted: rgba(26, 46, 56, .5);
  --border-color: rgba(13, 148, 136, .12);
  --code-bg: #eef4f6;
}

$phone-max-width: 683px;
$tablet-max-width: 899px;
$nav-collapse-width: 600px;

@import 'structure';
@import 'components';
