{% extends "base.html" %}
{% block title %}{{ page.title }} | {{ config.title }}{% endblock title %}
{% block content %}
<div class="page-content">
    <div class="post">
        {{ post_macros::header(page=page) }}
        {{ post_macros::content(page=page, summary=false, show_only_description=false) }}
    </div>
</div>
{% endblock content %}
