@import url('https://fonts.googleapis.com/css2?family=Rubik:ital,wght@0,400;0,500;0,700;1,400;1,500;1,700&display=swap');

// lime theme: neon green/yellow color scheme

:root {
  --accent: rgb(132, 204, 22);
  --accent-alpha-70: rgba(132, 204, 22, .7);
  --accent-alpha-20: rgba(132, 204, 22, .2);
  --accent-secondary: rgb(250, 204, 21);
  --accent-secondary-alpha-20: rgba(250, 204, 21, .2);
  --background: #0e1a08;
  --background-raised: #162410;
  --color: #e0f0c8;
  --color-muted: rgba(224, 240, 200, .5);
  --border-color: rgba(132, 204, 22, .15);
  --code-bg: rgba(0, 0, 0, 0.3);
  --max-width: 1200px;
}

[data-theme="light"] {
  --background: #f7fee7;
  --background-raised: #ffffff;
  --color: #1a2e08;
  --color-muted: rgba(26, 46, 8, .5);
  --border-color: rgba(132, 204, 22, .15);
  --code-bg: #ecfccb;
}

$phone-max-width: 683px;
$tablet-max-width: 899px;
$nav-collapse-width: 600px;

@import 'structure';
@import 'components';
