{% extends "base.html" %}
{% block title %}#{{ term.name }} | {{ config.title }}{% endblock title %}
{% block content %}
<div class="page-content">
    <div class="taxonomy-single">
        <h1>#{{ term.name }}</h1>
        <div class="posts">
        {%- for page in term.pages %}
            <div class="post on-list">
                {{ post_macros::header(page=page) }}
                {{ post_macros::content(page=page, summary=true, show_only_description=page.extra.show_only_description | default(value=false)) }}
            </div>
        {%- endfor %}
        </div>
    </div>
</div>
{% endblock content %}
